kvarn::prelude::utils::prelude::compact_str::core::ffi

Type Alias c_ushort

1.64.0 · source
pub type c_ushort = u16;
Equivalent to C’s unsigned short type.

This type will almost always be u16, but may differ on some esoteric systems. The C standard technically only requires that this type be an unsigned integer with the same size as a short.